pub struct Service {Show 16 fields
pub context_id: ContextId,
pub enabled: bool,
pub domain: Option<Vec<String>>,
pub service_id: ServiceId,
pub created: String,
pub updated: Option<String>,
pub prefix: String,
pub container_image: String,
pub container_image_version: Option<String>,
pub container_port: Option<i32>,
pub container_pull_user: Option<String>,
pub container_pull_pwd: Option<String>,
pub env_variables: Option<HashMap<String, JobResponseEnvVariablesValue>>,
pub rewrite: Option<Box<ServiceRewrite>>,
pub login: Option<Box<ServiceLogin>>,
pub mounts: Option<Vec<VolumeMount>>,
}Fields
context_id: ContextIdenabled: boolwhether this service is active and should be propagated to ingress
domain: Option<Vec<String>>by default this property is empty, this property is only populated if it was part of the service creation.
service_id: ServiceIdcreated: Stringupdated: Option<String>prefix: Stringcontainer_image: Stringcontainer_image_version: Option<String>container_port: Option<i32>Optional port to expose externally; when omitted the first open container port is exposed automatically.
container_pull_user: Option<String>container_pull_pwd: Option<String>env_variables: Option<HashMap<String, JobResponseEnvVariablesValue>>rewrite: Option<Box<ServiceRewrite>>login: Option<Box<ServiceLogin>>mounts: Option<Vec<VolumeMount>>Implementations